components/button/enums/v_button_layout_enum library

V Button Layout Enum This file defines the VButtonLayout enum which specifies the layout behavior of the VButton widget (e.g., hug content size or fill available space).

Enums

VButtonLayout
Enum representing different button layout options.

Extensions

VVButtonLayoutExtension on VButtonLayout
Extension on VButtonLayout to provide additional properties.