VButtonLayout enum

Enum representing different button layout options.

Inheritance
Available extensions

Values

WRAP → const VButtonLayout

Button hugs the content size.

const VButtonLayout(id: "WRAP", name: "Wrap")
FULL → const VButtonLayout

Button fills the available space.

const VButtonLayout(id: "FULL", name: "Full")

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
Unique identifier for the layout.
final
index int
A numeric identifier for the enumerated value.
no setterinherited
isFull bool
Checks if the layout is FULL.
no setter
isWrap bool
Checks if the layout is WRAP.
no setter
mainAxisSize MainAxisSize

Available on VButtonLayout, provided by the VVButtonLayoutExtension extension

Determines the main axis size based on the layout.
no setter
name String
Display name for the layout.
final
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<VButtonLayout>
A constant List of the values in this enum, in order of their declaration.