components/button/enums/v_button_shape_enum library

V Button Shape Enum This file defines the VButtonShape enum which specifies the shape of the VButton widget.

Enums

VButtonShape
Enum representing different shapes for a button.

Extensions

VButtonShapeRounded on VButtonShape
Extension on VButtonShape to provide additional properties.