VButtonSize enum

Enum representing different button sizes.

Inheritance
Available extensions

Values

SMALL → const VButtonSize

A small-sized button.

const VButtonSize(id: "SMALL", name: "Small")
MEDIUM → const VButtonSize

A medium-sized button.

const VButtonSize(id: "MEDIUM", name: "Medium")
LARGE → const VButtonSize

A large-sized button.

const VButtonSize(id: "LARGE", name: "Large")

Properties

fontSize double

Available on VButtonSize, provided by the VButtonSizeExtension extension

no setter
hashCode int
The hash code for this object.
no setterinherited
iconHeight double

Available on VButtonSize, provided by the VButtonSizeExtension extension

Returns icon height based on the button size.
no setter
iconSize double

Available on VButtonSize, provided by the VButtonSizeExtension extension

Returns icon size based on the button size.
no setter
iconWidth double

Available on VButtonSize, provided by the VButtonSizeExtension extension

Returns icon width based on the button size.
no setter
id String
Unique identifier for the size.
final
index int
A numeric identifier for the enumerated value.
no setterinherited
isLarge bool
Checks if the size is large.
no setter
isMedium bool
Checks if the size is medium.
no setter
isSmall bool
Checks if the size is small.
no setter
name String
Display name for the size.
final
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
padding EdgeInsetsGeometry

Available on VButtonSize, provided by the VButtonSizeExtension extension

Returns padding based on the button size.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size Size

Available on VButtonSize, provided by the VButtonSizeExtension extension

no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<VButtonSize>
A constant List of the values in this enum, in order of their declaration.