components/button/v_button library

Classes

VButton
A customizable button widget with multiple styles, sizes, and states.

Enums

VButtonColor
V Button Type Enum This file defines the VButtonType enum which specifies different types for the VButton widget. Enum representing different button types.
VButtonLayout
Enum representing different button layout options.
VButtonLoadingType
V Button Loading Type Enum This file defines the VButtonLoadingType enum which specifies the types of loading indicators that can be displayed on the VButton widget. Enum representing different loading indicator types for a button.
VButtonShape
Enum representing different shapes for a button.
VButtonSize
Enum representing different button sizes.
VButtonState
V Button State Enum This file defines the VButtonState enum which specifies different states for the VButton widget. Enum representing different button states.
VButtonType
V Button Border Enum This file defines the VButtonBorder enum which specifies different border styles for the VButton widget. Enum representing different button border styles.

Extensions

VButtonShapeRounded on VButtonShape
Extension on VButtonShape to provide additional properties.
VButtonSizeExtension on VButtonSize
Extension on VButtonSize to provide additional properties.
VButtonTypeExtension on VButtonType
Extension on VButtonBorder to provide additional properties if needed.
VVButtonLayoutExtension on VButtonLayout
Extension on VButtonLayout to provide additional properties.