DrawerContentDatePickerParams class

Constructors

DrawerContentDatePickerParams({required double itemExtent, double? diameterRatio, Color? backgroundColor, double? offAxisFraction, bool useMaginifier = true, double magnification = 1.0, required void onSelectedItemChanged(DateTime), TextStyle? selectedStyle, TextStyle? unselectedStyle, TextStyle? disabledStyle, DateTime? minDate, DateTime? maxDate, DateTime? selectedDate})

Properties

backgroundColor Color?
final
diameterRatio double?
final
disabledStyle TextStyle?
final
hashCode int
The hash code for this object.
no setterinherited
itemExtent double
final
magnification double
final
maxDate DateTime?
final
minDate DateTime?
final
offAxisFraction double?
final
onSelectedItemChanged → void Function(DateTime)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedDate DateTime?
final
selectedStyle TextStyle?
final
unselectedStyle TextStyle?
final
useMaginifier bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited