DrawerContentMultiSelectWithCheckboxParams<T> class

Constructors

DrawerContentMultiSelectWithCheckboxParams({required BuildContext context, Set<OptionData<T>>? initialValues, bool? isUseButton = true, required dynamic onItemsSelected(Set<OptionData<T>> selectedOptions), required Future<List<OptionData<T>>> initState(), BorderRadius? borderRadius, bool? withSearch, Widget? separator, String? searchHint, Widget? onLoading, Widget? onEmpty, Widget? onError, double height = 500, SearchTextFieldParamsWithCheckbox? searchParams})

Properties

borderRadius BorderRadius?
final
context BuildContext
final
hashCode int
The hash code for this object.
no setterinherited
height double
final
initialValues Set<OptionData<T>>?
final
initState Future<List<OptionData<T>>> Function()
final
isUseButton bool?
final
onEmpty Widget?
final
onError Widget?
final
onItemsSelected → dynamic Function(Set<OptionData<T>> selectedOptions)
final
onLoading Widget?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchHint String?
final
searchParams SearchTextFieldParamsWithCheckbox?
final
separator Widget?
final
withSearch bool?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited