DrawerContentSingleSelectParams<T> class

Constructors

DrawerContentSingleSelectParams({required BuildContext context, OptionData<T>? initialValue, bool? isUseButton = true, required dynamic onItemSelected(OptionData<T>? optionData), required Future<List<OptionData<T>>> initState(), BorderRadius? borderRadius, bool? withSearch, Widget? separator, String? searchHint, Widget? onLoading, Widget? onEmpty, Widget? onError, double height = 500, SearchTextFieldParams? searchParams})

Properties

borderRadius BorderRadius?
final
context BuildContext
final
hashCode int
The hash code for this object.
no setterinherited
height double
final
initialValue OptionData<T>?
final
initState Future<List<OptionData<T>>> Function()
final
isUseButton bool?
final
onEmpty Widget?
final
onError Widget?
final
onItemSelected → dynamic Function(OptionData<T>? optionData)
final
onLoading Widget?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchHint String?
final
searchParams SearchTextFieldParams?
final
separator Widget?
final
withSearch bool?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited