DrawerContentTimePickerParams class

Constructors

DrawerContentTimePickerParams.withButton({required dynamic buttonOnTap(int? hour, int? minute, int? second)?, String? buttonText, int? initValueHour, int? initValueMinute, int? initValueSecond, VentButtonStyle? buttonStyle, Color? overlayColor})
DrawerContentTimePickerParams.withoutButton({required dynamic onChange(int? hour, int? minute, int? second)?, int? initValueHour, int? initValueMinute, int? initValueSecond, Color? overlayColor})

Properties

buttonOnTap → dynamic Function(int? hour, int? minute, int? second)?
final
buttonStyle VentButtonStyle?
final
buttonText String?
final
hashCode int
The hash code for this object.
no setterinherited
initValueHour int?
final
initValueMinute int?
final
initValueSecond int?
final
isUseButton bool
final
onChange → dynamic Function(int? hour, int? minute, int? second)?
final
overlayColor Color?
this color , will be use withOpacity (0.5)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited