build method

  1. @override
Widget build(
  1. BuildContext context
)
override

Describes the part of the user interface represented by this widget.

The framework calls this method when this widget is inserted into the tree in a given BuildContext and when the dependencies of this widget change (e.g., an InheritedWidget referenced by this widget changes). This method can potentially be called in every frame and should not have any side effects beyond building a widget.

The framework replaces the subtree below this widget with the widget returned by this method, either by updating the existing subtree or by removing the subtree and inflating a new subtree, depending on whether the widget returned by this method can update the root of the existing subtree, as determined by calling Widget.canUpdate.

Typically implementations return a newly created constellation of widgets that are configured with information from this widget's constructor and from the given BuildContext.

The given BuildContext contains information about the location in the tree at which this widget is being built. For example, the context provides the set of inherited widgets for this location in the tree. A given widget might be built with multiple different BuildContext arguments over time if the widget is moved around the tree or if the widget is inserted into the tree in multiple places at once.

The implementation of this method must only depend on:

If a widget's build method is to depend on anything else, use a StatefulWidget instead.

See also:

  • StatelessWidget, which contains the discussion on performance considerations.

Implementation

@override
Widget build(BuildContext context) {
  /// init value time picker.
  int selectedHour = params.initValueHour ?? DateTime.now().hour;
  int selectedMinute = params.initValueMinute ?? DateTime.now().minute;
  int selectedSecond = params.initValueSecond ?? DateTime.now().second;

  // get value
  void getValueTimePicker() {
    if (params.onChange == null) return;
    params.onChange?.call(selectedHour, selectedMinute, selectedSecond);
  }

  // Fungsi untuk menghasilkan daftar angka dari 0 sampai maxNumber
  List<Widget> generateNumberList(int maxNumber) {
    return List<Widget>.generate(maxNumber, (int index) {
      return Center(
        child: Text(
          index.toString().padLeft(2, '0'), // Menggunakan dua digit angka (misalnya 01, 02)
          style: const TextStyle(
            fontSize: 22,
            // color: VentColorSwatch.Gray.shade900,
            color: Colors.black,
          ), // Custom style
        ),
      );
    });
  }

  return SizedBox(
    height: 250, // Tinggi modal sheet
    child: Column(
      children: [
        /// time picker
        Expanded(
          child: Row(
            mainAxisAlignment: MainAxisAlignment.center,
            children: [
              Expanded(
                child: Container(
                  width: double.infinity,
                  height: 50,
                  decoration: BoxDecoration(
                      color: (params.overlayColor ?? VentColorSwatch.Primary.shade100)
                          .withOpacity(.5),
                      borderRadius: const BorderRadius.horizontal(
                        left: Radius.circular(8),
                      )),
                ),
              ),
              Expanded(
                child: CupertinoPicker(
                  itemExtent: 50, // Tinggi setiap item
                  useMagnifier: true,
                  selectionOverlay: Container(
                    width: double.infinity,
                    height: 50,
                    decoration: BoxDecoration(
                      color: (params.overlayColor ?? VentColorSwatch.Primary.shade100)
                          .withOpacity(.5),
                    ),
                  ),
                  onSelectedItemChanged: (int index) {
                    selectedHour = index;
                    if (!params.isUseButton) getValueTimePicker();
                  }, // List dari 0-23 untuk jam
                  scrollController: FixedExtentScrollController(initialItem: selectedHour),
                  children: generateNumberList(
                    24,
                  ),
                ),
              ),
              Expanded(
                child: CupertinoPicker(
                  itemExtent: 50, // Tinggi setiap item
                  selectionOverlay: Container(
                    width: double.infinity,
                    height: 50,
                    color:
                        (params.overlayColor ?? VentColorSwatch.Primary.shade100).withOpacity(.5),
                  ),
                  onSelectedItemChanged: (int index) {
                    selectedMinute = index;
                    if (!params.isUseButton) getValueTimePicker();
                  }, // List dari 0-59 untuk menit
                  scrollController: FixedExtentScrollController(initialItem: selectedMinute),
                  children: generateNumberList(60),
                ),
              ),
              Expanded(
                child: CupertinoPicker(
                  itemExtent: 50, // Tinggi setiap item
                  selectionOverlay: Container(
                    width: double.infinity,
                    height: 50,
                    decoration: BoxDecoration(
                      color: (params.overlayColor ?? VentColorSwatch.Primary.shade100)
                          .withOpacity(.5),
                    ),
                  ),
                  onSelectedItemChanged: (int index) {
                    selectedSecond = index;
                    if (!params.isUseButton) getValueTimePicker();
                  }, // List dari 0-59 untuk detik
                  scrollController: FixedExtentScrollController(initialItem: selectedSecond),
                  children: generateNumberList(60),
                ),
              ),
              Expanded(
                child: Container(
                  width: double.infinity,
                  height: 50,
                  decoration: BoxDecoration(
                    color:
                        (params.overlayColor ?? VentColorSwatch.Primary.shade100).withOpacity(.5),
                    borderRadius: const BorderRadius.horizontal(right: Radius.circular(8)),
                  ),
                ),
              ),
            ],
          ),
        ),

        if (params.isUseButton) ...[
          const SizedBox(height: 25),
          VentButton(
            buttonText: params.buttonText ?? "Tutup",
            onTap: () {
              if (params.buttonOnTap != null) {
                params.buttonOnTap?.call(selectedHour, selectedMinute, selectedSecond);
              }

              /// trigger return value.
              getValueTimePicker();

              /// back.
              Navigator.pop(context);
            },
            buttonStyle: params.buttonStyle ??
                VentButtonStyle.filled(
                  buttonSize: ButtonSize.LARGE,
                  width: double.infinity,
                ),
          ),
        ],
      ],
    ),
  );
}