OptionData<T> class

Constructors

OptionData({required String id, required String label, required T data})

Properties

data → T
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
isSelected bool
getter/setter pair
label String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited