VentDrawerService class

Constructors

VentDrawerService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

showDrawerDatePicker({required GeneralParamsDrawer generalParams, required DrawerContentDatePickerParams contentParams}) Future
showDrawerGeneral<T>({required GeneralParamsDrawer? params, required Widget content}) Future<T?>
showDrawerMultipleSelectWithCheckbox<T>({required GeneralParamsDrawer generalParams, required DrawerContentMultiSelectWithCheckboxParams<T> contentParams}) Future
showDrawerSingleSelect<T>({required GeneralParamsDrawer generalParams, required DrawerContentSingleSelectParams<T> contentParams}) Future
showDrawerSingleSelectWithRadio<T>({required GeneralParamsDrawer generalParams, required DrawerContentSingleSelectWithRadioParams<T> contentParams}) Future
showDrawerTimePickerWithButton({required GeneralParamsDrawer generalParams, required DrawerContentTimePickerParams contentParams}) Future
showDrawerTimePickerWithoutButton({required GeneralParamsDrawer generalParams, required DrawerContentTimePickerParams contentParams}) Future
showDrawerUnderConstruction<T>({required GeneralParamsDrawer generalParams, dynamic onTap()?, String? titleContent, String? descContent, String? imagePath, String? buttonText, bool isUseButton = false}) Future<T?>