Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- add_plus_filled ↔ VIconData
-
getter/setter pair
- add_plus_outlined ↔ VIconData
-
getter/setter pair
- alert_circle_filled ↔ VIconData
-
getter/setter pair
- alert_circle_outlined ↔ VIconData
-
getter/setter pair
- alert_triangle_filled ↔ VIconData
-
getter/setter pair
- alert_triangle_outlined ↔ VIconData
-
getter/setter pair
- arrow_carret_down_filled ↔ VIconData
-
getter/setter pair
- arrow_carret_down_outlined ↔ VIconData
-
getter/setter pair
- arrow_carret_left_filled ↔ VIconData
-
getter/setter pair
- arrow_carret_left_outlined ↔ VIconData
-
getter/setter pair
- arrow_carret_right_filled ↔ VIconData
-
getter/setter pair
- arrow_carret_right_outlined ↔ VIconData
-
getter/setter pair
- arrow_carret_up_filled ↔ VIconData
-
getter/setter pair
- arrow_carret_up_outlined ↔ VIconData
-
getter/setter pair
- arrow_down_filled ↔ VIconData
-
getter/setter pair
- arrow_down_outlined ↔ VIconData
-
getter/setter pair
- arrow_flip_rotate_filled ↔ VIconData
-
getter/setter pair
- arrow_flip_rotate_outlined ↔ VIconData
-
getter/setter pair
- arrow_right_filled ↔ VIconData
-
getter/setter pair
- arrow_right_outlined ↔ VIconData
-
getter/setter pair
- arrow_up_filled ↔ VIconData
-
getter/setter pair
- arrow_up_outlined ↔ VIconData
-
getter/setter pair
- arrow_zoom_out_filled ↔ VIconData
-
getter/setter pair
- arrow_zoom_out_outlined ↔ VIconData
-
getter/setter pair
- bank_filled ↔ VIconData
-
getter/setter pair
- bank_outlined ↔ VIconData
-
getter/setter pair
- barcode_filled ↔ VIconData
-
getter/setter pair
- barcode_outlined ↔ VIconData
-
getter/setter pair
- blank_papper_filled ↔ VIconData
-
getter/setter pair
- blank_papper_outlined ↔ VIconData
-
getter/setter pair
- block_circle_filled ↔ VIconData
-
getter/setter pair
- block_circle_outlined ↔ VIconData
-
getter/setter pair
- book_filled ↔ VIconData
-
getter/setter pair
- book_outlined ↔ VIconData
-
getter/setter pair
- bookmark_collection_filled ↔ VIconData
-
getter/setter pair
- bookmark_collection_outlined ↔ VIconData
-
getter/setter pair
- calculator_filled ↔ VIconData
-
getter/setter pair
- calculator_outlined ↔ VIconData
-
getter/setter pair
- camera_filled ↔ VIconData
-
getter/setter pair
- camera_outlined ↔ VIconData
-
getter/setter pair
- car_front_filled ↔ VIconData
-
getter/setter pair
- car_front_outlined ↔ VIconData
-
getter/setter pair
- chat_circle_filled ↔ VIconData
-
getter/setter pair
- chat_circle_outlined ↔ VIconData
-
getter/setter pair
- circle_arrow_carret_left_filled ↔ VIconData
-
getter/setter pair
- circle_arrow_carret_left_outlined ↔ VIconData
-
getter/setter pair
- circle_arrow_carret_right_filled ↔ VIconData
-
getter/setter pair
- circle_arrow_carret_right_outlined ↔ VIconData
-
getter/setter pair
- circle_arrow_down_filled ↔ VIconData
-
getter/setter pair
- circle_arrow_down_outlined ↔ VIconData
-
getter/setter pair
- circle_arrow_left_filled ↔ VIconData
-
getter/setter pair
- circle_arrow_left_outlined ↔ VIconData
-
getter/setter pair
- circle_arrow_right_filled ↔ VIconData
-
getter/setter pair
- circle_arrow_right_outlined ↔ VIconData
-
getter/setter pair
- circle_arrow_up_filled ↔ VIconData
-
getter/setter pair
- circle_arrow_up_outlined ↔ VIconData
-
getter/setter pair
- three_dots_horizontal_filled ↔ VIconData
-
getter/setter pair
- three_dots_horizontal_outlined ↔ VIconData
-
getter/setter pair
- three_dots_vertical_filled ↔ VIconData
-
getter/setter pair
- three_dots_vertical_outlined ↔ VIconData
-
getter/setter pair