VImages class

Inheritance
Available extensions

Constructors

VImages(VImageData image, {Widget frameBuilder(BuildContext, Widget, int?, bool)?, Widget loadingBuilder(BuildContext, Widget, ImageChunkEvent?)?, Widget errorBuilder(BuildContext, Object, StackTrace?)?, String? semanticLabel, bool excludeFromSemantics, double? width, double? height, Color? color, Animation<double>? opacity, BlendMode? colorBlendMode, BoxFit? fit, AlignmentGeometry alignment, ImageRepeat repeat, Rect? centerSlice, bool matchTextDirection, bool gaplessPlayback, bool isAntiAlias, FilterQuality filterQuality})
const
factory
VImages.asset(String asset, {Widget frameBuilder(BuildContext, Widget, int?, bool)?, Widget loadingBuilder(BuildContext, Widget, ImageChunkEvent?)?, Widget errorBuilder(BuildContext, Object, StackTrace?)?, String? semanticLabel, bool excludeFromSemantics, double? width, double? height, Color? color, Animation<double>? opacity, BlendMode? colorBlendMode, BoxFit? fit, AlignmentGeometry alignment, ImageRepeat repeat, Rect? centerSlice, bool matchTextDirection, bool gaplessPlayback, bool isAntiAlias, FilterQuality filterQuality})
const
factory
VImages.memory(Uint8List asset, {Widget frameBuilder(BuildContext, Widget, int?, bool)?, Widget loadingBuilder(BuildContext, Widget, ImageChunkEvent?)?, Widget errorBuilder(BuildContext, Object, StackTrace?)?, String? semanticLabel, bool excludeFromSemantics, double? width, double? height, Color? color, Animation<double>? opacity, BlendMode? colorBlendMode, BoxFit? fit, AlignmentGeometry alignment, ImageRepeat repeat, Rect? centerSlice, bool matchTextDirection, bool gaplessPlayback, bool isAntiAlias, FilterQuality filterQuality})
const
factory
VImages.network(String asset, {Widget frameBuilder(BuildContext, Widget, int?, bool)?, Widget loadingBuilder(BuildContext, Widget, ImageChunkEvent?)?, Widget errorBuilder(BuildContext, Object, StackTrace?)?, String? semanticLabel, bool excludeFromSemantics, double? width, double? height, Color? color, Animation<double>? opacity, BlendMode? colorBlendMode, BoxFit? fit, AlignmentGeometry alignment, ImageRepeat repeat, Rect? centerSlice, bool matchTextDirection, bool gaplessPlayback, bool isAntiAlias, FilterQuality filterQuality})
const
factory

Properties

alignment AlignmentGeometry
final
centerSlice Rect?
final
color Color?
final
colorBlendMode BlendMode?
final
errorBuilder Widget Function(BuildContext, Object, StackTrace?)?
final
excludeFromSemantics bool
final
filterQuality FilterQuality
final
fit BoxFit?
final
frameBuilder Widget Function(BuildContext, Widget, int?, bool)?
final
gaplessPlayback bool
final
hashCode int
The hash code for this object.
no setterinherited
height double?
final
image VImageData?
final
imageProvider ImageProvider<Object>
final
isAntiAlias bool
final
isPackage bool
no setter
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loadingBuilder Widget Function(BuildContext, Widget, ImageChunkEvent?)?
final
matchTextDirection bool
final
opacity Animation<double>?
final
repeat ImageRepeat
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticLabel String?
final
width double?
final

Methods

backgroundColor({Color color = Colors.transparent}) Widget

Available on Widget, provided by the WidgetExtension extension

borderRadius({double? topLeft, double? topRight, double? bottomLeft, double? bottomRight, double? verticalTop, double? verticalBottom, double? horizontalLeft, double? horizontalRight, double? all}) Widget

Available on Widget, provided by the WidgetExtension extension

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
errorWidget(BuildContext context, Object error, StackTrace? stackTrace) Widget
frameWidget(BuildContext context, Widget child, int? frame, bool wasSynchronouslyLoaded) Widget
innerShadow({double? width, double? height, Color? shadowColor}) Widget

Available on Widget, provided by the WidgetExtension extension

loadingWidget(BuildContext context, Widget child, ImageChunkEvent? loadingProgress) Widget
margin({double? horizontal, double? vertical, double? top, double? right, double? bottom, double? left, double? all}) Widget

Available on Widget, provided by the WidgetExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
provider(String asset) ImageProvider<Object>
semantics(KatalonIdentifier katalonIdentifier) Widget

Available on Widget, provided by the WidgetExtension extension

shimmer({Color baseColor = const Color(0xFFd2d2d2), Color highlightColor = Colors.white}) Widget

Available on Widget, provided by the WidgetExtension extension

skeletonizer({Color baseColor = const Color(0xFFd2d2d2), Color highlightColor = Colors.white, double borderRadius = 6}) Widget

Available on Widget, provided by the WidgetExtension extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited