VentBottomBar<T> class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- VentBottomBar
- Available extensions
Constructors
-
VentBottomBar({Key? key, required List<
VentBottomBarItem< items, required void onPressed(VentBottomBarItem<T> >T> ? item), VentBottomBarItem<T> ? initialItem, double height = 66, VentBottomBarDecoration decoration = const VentBottomBarDecoration()}) -
const
Properties
- decoration → VentBottomBarDecoration
-
final
-
fabIndex
→ List<
int> -
no setter
-
fabItem
→ (VentBottomBarItem<
T> ?, int)? -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
final
-
initialItem
→ VentBottomBarItem<
T> ? -
final
-
items
→ List<
VentBottomBarItem< T> > -
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
onPressed
→ void Function(VentBottomBarItem<
T> ? item) -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
backgroundColor(
{Color color = Colors.transparent}) → Widget -
Available on Widget, provided by the WidgetExtension extension
-
borderRadius(
{double? topLeft, double? topRight, double? bottomLeft, double? bottomRight, double? verticalTop, double? verticalBottom, double? horizontalLeft, double? horizontalRight, double? all}) → Widget -
Available on Widget, provided by the WidgetExtension extension
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
innerShadow(
{double? width, double? height, Color? shadowColor}) → Widget -
Available on Widget, provided by the WidgetExtension extension
-
margin(
{double? horizontal, double? vertical, double? top, double? right, double? bottom, double? left, double? all}) → Widget -
Available on Widget, provided by the WidgetExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
semantics(
KatalonIdentifier katalonIdentifier) → Widget -
Available on Widget, provided by the WidgetExtension extension
-
shimmer(
{Color baseColor = const Color(0xFFd2d2d2), Color highlightColor = Colors.white}) → Widget -
Available on Widget, provided by the WidgetExtension extension
-
skeletonizer(
{Color baseColor = const Color(0xFFd2d2d2), Color highlightColor = Colors.white, double borderRadius = 6}) → Widget -
Available on Widget, provided by the WidgetExtension extension
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited