VentBottomBarDecoration class

Constructors

VentBottomBarDecoration({Color activeColor = VentColorSwatch.Primary, Color inactiveColor = const Color(0xFFB5B7C4), Color disableColor = const Color.fromARGB(255, 224, 226, 235), Color backgroundColor = Colors.white, Color badgeColor = VentColorSwatch.Danger, TextStyle textStyle = const TextStyle(fontWeight: FontWeight.w500, fontSize: 12), Size iconSize = const Size(24, 24)})
const

Properties

activeColor Color
final
backgroundColor Color
final
badgeColor Color
final
disableColor Color
final
hashCode int
The hash code for this object.
no setterinherited
iconSize Size
final
inactiveColor Color
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textStyle TextStyle
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited