VentBottomBarItem<T> class

Constructors

VentBottomBarItem({required T id, required dynamic icon, required String label, int badge = 0, dynamic shadowColor = Colors.transparent})
VentBottomBarItem.fab({required T id, required dynamic icon, required String label, int badge = 0, double fabStrokeWidth = 5, double fabRadius = 54, double fabHeight = 66 / 2, double fabBorderRadius = 999, Color shadowColor = const Color(0x30686868), Color fabStrokeColor = Colors.white, Color fabBackgroundColor = VentColorSwatch.Primary, Color fabForegroundColor = Colors.white})

Properties

badge int
final
fabBackgroundColor Color
final
fabBorderRadius double
final
fabForegroundColor Color
final
fabHeight double
final
fabRadius double
final
fabStrokeColor Color
final
fabStrokeWidth double
final
hashCode int
The hash code for this object.
no setterinherited
icon → dynamic
final
id → T
final
isFab bool
final
label String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shadowColor Color
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited