VentSliderDecoration class

Constructors

VentSliderDecoration({Color? bacgroundColor = const Color(0xFFEEEEEE), Color? foregroundColor = VentColorSwatch.Primary, Color? thumbColor = VentColorSwatch.Primary, double? thumbRadius = 16, double? strokeSize = 3})

Properties

bacgroundColor Color?
final
foregroundColor Color?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strokeSize double?
final
thumbColor Color?
final
thumbRadius double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited