VTextFieldShape enum

Inheritance
Available extensions

Values

SQUARE → const VTextFieldShape
const VTextFieldShape(id: "SQUARE", name: "Square")
ROUNDED → const VTextFieldShape
const VTextFieldShape(id: "ROUNDED", name: "Rounded")
CIRCLE → const VTextFieldShape
const VTextFieldShape(id: "CIRCLE", name: "Circle")

Properties

borderRadius double

Available on VTextFieldShape, provided by the VTextFieldShapeExtension extension

no setter
hashCode int
The hash code for this object.
no setterinherited
id String
final
index int
A numeric identifier for the enumerated value.
no setterinherited
isCircle bool
no setter
isRounded bool
no setter
isSquare bool
no setter
name String
final
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<VTextFieldShape>
A constant List of the values in this enum, in order of their declaration.