VTextField class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- VTextField
- Available extensions
Constructors
- VTextField({Key? key, required TextEditingController controller, String? label, String? placeHolder, void onChanged(String)?, void onEditingComplete()?, void onFieldSubmitted(String)?, void onSaved(String?)?, bool obsecure = false, Widget? iconPreffix, Widget? iconSuffix, VTextFieldValidator inputValidator = VTextFieldValidator.NO, int? maxLength, int? minLength, TextInputAction? textInputAction = TextInputAction.done, VTextFieldShape shape = VTextFieldShape.ROUNDED, VTextFieldLine line = const VTextFieldLine.single(), VTextFieldLabelType labelType = VTextFieldLabelType.OUTTER, VTextFieldBorderType borderType = VTextFieldBorderType.OUTLINED, bool isDisable = false})
-
factory
Properties
- borderType → VTextFieldBorderType
-
final
- controller → TextEditingController
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- iconPreffix → Widget?
-
final
- iconSuffix → Widget?
-
final
- inputValidator → VTextFieldValidator
-
final
- isDisable → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- label → String?
-
final
- labelType → VTextFieldLabelType
-
final
- line → VTextFieldLine
-
final
- maxLength → int?
-
final
- minLength → int?
-
final
- obsecure → bool
-
final
- onChanged → void Function(String)?
-
final
- onEditingComplete → void Function()?
-
final
- onFieldSubmitted → void Function(String)?
-
final
- onSaved → void Function(String?)?
-
final
- placeHolder → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shape → VTextFieldShape
-
final
- textInputAction → TextInputAction?
-
final
Methods
-
backgroundColor(
{Color color = Colors.transparent}) → Widget -
Available on Widget, provided by the WidgetExtension extension
-
borderRadius(
{double? topLeft, double? topRight, double? bottomLeft, double? bottomRight, double? verticalTop, double? verticalBottom, double? horizontalLeft, double? horizontalRight, double? all}) → Widget -
Available on Widget, provided by the WidgetExtension extension
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
copyWith(
{Key? key}) → VTextField -
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
innerShadow(
{double? width, double? height, Color? shadowColor}) → Widget -
Available on Widget, provided by the WidgetExtension extension
-
margin(
{double? horizontal, double? vertical, double? top, double? right, double? bottom, double? left, double? all}) → Widget -
Available on Widget, provided by the WidgetExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
semantics(
KatalonIdentifier katalonIdentifier) → Widget -
Available on Widget, provided by the WidgetExtension extension
-
shimmer(
{Color baseColor = const Color(0xFFd2d2d2), Color highlightColor = Colors.white}) → Widget -
Available on Widget, provided by the WidgetExtension extension
-
skeletonizer(
{Color baseColor = const Color(0xFFd2d2d2), Color highlightColor = Colors.white, double borderRadius = 6}) → Widget -
Available on Widget, provided by the WidgetExtension extension
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited