VentWalletDecoration class
Constructors
- VentWalletDecoration({Color? activeColor, Color? disableColor, Color? backgroundColor, BorderRadiusGeometry? borderRadius})
Properties
- activeColor → Color?
-
final
- backgroundColor → Color?
-
final
- borderRadius → BorderRadiusGeometry?
-
final
- disableColor → Color?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited