VentWalletScanDecoration class

Constructors

VentWalletScanDecoration({Size? size, String? asset, EdgeInsetsGeometry? padding, Color? borderColor, double? borderThickness, BorderRadiusGeometry? borderRadius})

Properties

asset String?
final
borderColor Color?
final
borderRadius BorderRadiusGeometry?
final
borderThickness double?
final
hashCode int
The hash code for this object.
no setterinherited
padding EdgeInsetsGeometry?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size Size?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited