VentWalletTile class

Constructors

VentWalletTile({Widget? icon, required String label, required String value, dynamic onValuePressed()?, VentWalletTileDecoration? decoration, Widget? suffixValue})
VentWalletTile.obsecure({Widget? icon, required String label, bool? obsecure = true, required String value, dynamic onObsecureChanged(bool obsecure)?, dynamic onValuePressed()?, VentWalletTileDecoration? decoration, Widget? suffixValue, required bool initialValue})

Properties

decoration VentWalletTileDecoration?
final
hashCode int
The hash code for this object.
no setterinherited
icon Widget?
final
initialValue bool
getter/setter pair
label String
final
obsecure bool?
final
onObsecureChanged → dynamic Function(bool obsecure)?
final
onValuePressed → dynamic Function()?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
suffixValue Widget?
final
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited