DioErrorLocalization class
- Inheritance
-
- Object
- AbsLocalization
- DioErrorLocalization
Constructors
Properties
-
enDictionary
→ Map<
String, String> -
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
idDictionary
→ Map<
String, String> -
no setterinherited
-
listDictionary
↔ List<
VLocalizationModel> -
getter/setter pairoverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- dioError400 ↔ VLocalizationModel
-
getter/setter pair
- dioError401 ↔ VLocalizationModel
-
getter/setter pair
- dioError403 ↔ VLocalizationModel
-
getter/setter pair
- dioError404 ↔ VLocalizationModel
-
getter/setter pair
- dioError405 ↔ VLocalizationModel
-
getter/setter pair
- dioError415 ↔ VLocalizationModel
-
getter/setter pair
- dioError422 ↔ VLocalizationModel
-
getter/setter pair
- dioError429 ↔ VLocalizationModel
-
getter/setter pair
- dioError500 ↔ VLocalizationModel
-
getter/setter pair
- dioErrorDefault ↔ VLocalizationModel
-
getter/setter pair
- dioExceptionTypeCancel ↔ VLocalizationModel
-
getter/setter pair
- dioExceptionTypeConnectionError ↔ VLocalizationModel
-
getter/setter pair
- dioExceptionTypeConnectionTimeout ↔ VLocalizationModel
-
getter/setter pair
- dioExceptionTypeReceiveTimeout ↔ VLocalizationModel
-
getter/setter pair
- dioExceptionTypeSecurityValidationFailed ↔ VLocalizationModel
-
getter/setter pair
- dioExceptionTypeSendTimeout ↔ VLocalizationModel
-
getter/setter pair
- dioExceptionTypeUnknown ↔ VLocalizationModel
-
getter/setter pair
- dioExceptionTypeUnknownNoInternetConnection ↔ VLocalizationModel
-
getter/setter pair
- securityBlockedAccess ↔ VLocalizationModel
-
getter/setter pair
- systemError ↔ VLocalizationModel
-
getter/setter pair