BannerMessagingDecorationEnum enum
Values
- DANGER → const BannerMessagingDecorationEnum
-
const BannerMessagingDecorationEnum(iconSize: 20, bgColor: Color(0xFFFEEDEE), itemColor: Color(0xFFF46D73), textStyle: TextStyle(fontSize: 14, fontWeight: FontWeight.w500, color: Color(0xFFF46D73)), w… - PRIMARY → const BannerMessagingDecorationEnum
-
const BannerMessagingDecorationEnum(iconSize: 20, bgColor: Color(0xFFEAF4F6), itemColor: Color(0xFF2C8DA2), textStyle: TextStyle(fontSize: 14, fontWeight: FontWeight.w500, color: Color(0xFF2C8DA2)), w… - WARNING → const BannerMessagingDecorationEnum
-
const BannerMessagingDecorationEnum(iconSize: 20, bgColor: Color(0xFFFFF9E6), itemColor: Color(0xFFE8B006), textStyle: TextStyle(fontSize: 14, fontWeight: FontWeight.w500, color: Color(0xFFE8B006)), w… - SUCCESS → const BannerMessagingDecorationEnum
-
const BannerMessagingDecorationEnum(iconSize: 20, bgColor: Color(0xFFEBF9F4), itemColor: Color(0xFF2EB581), textStyle: TextStyle(fontSize: 14, fontWeight: FontWeight.w500, color: Color(0xFF2EB581)), w… - INFO → const BannerMessagingDecorationEnum
-
const BannerMessagingDecorationEnum(iconSize: 20, bgColor: Color(0xFFEEF1FC), itemColor: Color(0xFF5275DF), textStyle: TextStyle(fontSize: 14, fontWeight: FontWeight.w500, color: Color(0xFF5275DF)), w…
Properties
- bgColor → Color
-
final
- gapPadding → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- iconSize → double
-
final
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- itemColor → Color
-
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - padding → EdgeInsets
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textStyle → TextStyle
-
final
- width → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
BannerMessagingDecorationEnum> - A constant List of the values in this enum, in order of their declaration.