State enum

Inheritance
Available extensions

Values

idle → const State
loading → const State
success → const State
activeQuestion → const State
error → const State
empty → const State

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
isActiveQuestion bool
no setter
isEmpty bool
no setter
isError bool
no setter
isIdle bool
no setter
isLoading bool
no setter
isSuccess bool
no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<State>
A constant List of the values in this enum, in order of their declaration.