KatalonIdentifier class

Constructors

KatalonIdentifier({required String id, String? route = 'general', Type? type, String? widgetName = 'widget', String? attributeId})
KatalonIdentifier.general({required String id, String? widgetName = 'widget', String? route = 'general', Type? type})

Properties

attributeId String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
identifier String
no setter
route String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type Type?
final
widgetName String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited