VLocalizationModel class

Available extensions

Constructors

VLocalizationModel({String key = '', required String idValue, required String enValue})

Properties

enValue String
final
getEN Map<String, String>
no setter
getID Map<String, String>
no setter
hashCode int
The hash code for this object.
no setterinherited
idValue String
final
key String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
tr([String local = "id_ID"]) String

Available on VLocalizationModel, provided by the VLocalizationModelExtension extension

Operators

operator ==(Object other) bool
The equality operator.
inherited