VPackThemeData class

Constructors

VPackThemeData({VButtonThemeData buttonTheme = const VButtonThemeData(), VColorData colorTheme = const VColorData(), TextStyle textStyle = const TextStyle(fontFamily: "Manrope")})
const

Properties

buttonTheme VButtonThemeData
final
colorTheme VColorData
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textStyle TextStyle
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited