components/button/enums/v_button_border_enum library
Enums
- VButtonType
- V Button Border Enum This file defines the VButtonBorder enum which specifies different border styles for the VButton widget. Enum representing different button border styles.
Extensions
- VButtonTypeExtension on VButtonType
- Extension on VButtonBorder to provide additional properties if needed.