VButtonState enum
V Button State Enum This file defines the VButtonState enum which specifies different states for the VButton widget. Enum representing different button states.
Values
- SUCCESS → const VButtonState
-
Indicates that the button is in a success state.
const VButtonState(id: "SUCCESS", name: "Success") - DISABLE → const VButtonState
-
Indicates that the button is disabled.
const VButtonState(id: "DISABLE", name: "Disable") - LOADING → const VButtonState
-
Indicates that the button is loading.
const VButtonState(id: "LOADING", name: "Loading")
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Unique identifier for the state.
final
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- isDisable → bool
-
Checks if the state is disabled.
no setter
- isLoading → bool
-
Checks if the state is loading.
no setter
- isSuccess → bool
-
Checks if the state is success.
no setter
- name → String
-
Display name for the state.
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
VButtonState> - A constant List of the values in this enum, in order of their declaration.