SearchTextFieldParamsWithRadio class
Constructors
- SearchTextFieldParamsWithRadio({TextStyle? customTextStyle, TextInputType? textInputType, String? hint = "Search Data ...", Widget? suffixWidget, Widget? prefixWidget, dynamic onSubmit(String? value)?, bool readOnly = false, bool isDense = false, Color? fillColor, Color? hintColor, Color? iconColor, BoxBorder? border, BoxBorder? focusedBorder, EdgeInsets? padding, dynamic onTap()?, TextInputAction? textInputAction, double? radius, bool autoFocus = false, bool useClearTextField = true, dynamic addFunction()?})
Properties
- addFunction → dynamic Function()?
-
final
- autoFocus → bool
-
final
- border → BoxBorder?
-
final
- customTextStyle → TextStyle?
-
final
- fillColor → Color?
-
final
- focusedBorder → BoxBorder?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hint → String?
-
final
- hintColor → Color?
-
final
- iconColor → Color?
-
final
- isDense → bool
-
final
- onSubmit → dynamic Function(String? value)?
-
final
- onTap → dynamic Function()?
-
final
- padding → EdgeInsets?
-
final
- prefixWidget → Widget?
-
final
- radius → double?
-
final
- readOnly → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- suffixWidget → Widget?
-
final
- textInputAction → TextInputAction?
-
final
- textInputType → TextInputType?
-
final
- useClearTextField → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited