GeneralParamsDrawer class
Constructors
- GeneralParamsDrawer({required BuildContext context, bool withStrip = true, double? radius, double? marginTop = 0, bool isDismissable = true, EdgeInsets? padding, double? paddingBottom, RouteSettings? settings, bool isScrollControlled = true, bool enableDrag = true, String? titleHeader = "Select Data", String? subTitleHeader = "Select data please", void onTapIconClose()?, bool isUseHeader = false})
Properties
- context → BuildContext
-
final
- enableDrag → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDismissable → bool
-
final
- isScrollControlled → bool
-
final
- isUseHeader → bool
-
final
- marginTop → double?
-
final
- onTapIconClose → void Function()?
-
final
- padding → EdgeInsets?
-
final
- paddingBottom → double?
-
final
- radius → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- settings → RouteSettings?
-
final
- subTitleHeader → String?
-
final
- titleHeader → String?
-
final
- withStrip → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited