VentBottomBarItem<T> class
Constructors
-
VentBottomBarItem({required T id, required dynamic icon, required String label, int badge = 0, dynamic shadowColor = Colors.transparent})
-
-
VentBottomBarItem.fab({required T id, required dynamic icon, required String label, int badge = 0, double fabStrokeWidth = 5, double fabRadius = 54, double fabHeight = 66 / 2, double fabBorderRadius = 999, Color shadowColor = const Color(0x30686868), Color fabStrokeColor = Colors.white, Color fabBackgroundColor = VentColorSwatch.Primary, Color fabForegroundColor = Colors.white})
-
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited