VentWalletTile class
Constructors
-
VentWalletTile({Widget? icon, required String label, required String value, dynamic onValuePressed()?, VentWalletTileDecoration? decoration, Widget? suffixValue})
-
-
VentWalletTile.obsecure({Widget? icon, required String label, bool? obsecure = true, required String value, dynamic onObsecureChanged(bool obsecure)?, dynamic onValuePressed()?, VentWalletTileDecoration? decoration, Widget? suffixValue, required bool initialValue})
-
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited