VentWalletTileDecoration class
Constructors
- VentWalletTileDecoration({TextStyle? labelStyle, TextStyle? valueStyle, Color? obsecureColor, EdgeInsetsGeometry? padding, double? obsecureIconSize})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- labelStyle → TextStyle?
-
final
- obsecureColor → Color?
-
final
- obsecureIconSize → double?
-
final
- padding → EdgeInsetsGeometry?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- valueStyle → TextStyle?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited